@@ -9,19 +9,19 @@
 #include "units.h"
 
 KirigamiPlasmaFactory::KirigamiPlasmaFactory(QObject *parent)
-    : Kirigami::KirigamiPluginFactoryV2(parent)
+    : Kirigami::Platform::PlatformPluginFactory(parent)
 {
 }
 
 KirigamiPlasmaFactory::~KirigamiPlasmaFactory() = default;
 
-Kirigami::PlatformTheme *KirigamiPlasmaFactory::createPlatformTheme(QObject *parent)
+Kirigami::Platform::PlatformTheme *KirigamiPlasmaFactory::createPlatformTheme(QObject *parent)
 {
     Q_ASSERT(parent);
     return new PlasmaDesktopTheme(parent);
 }
 
-Kirigami::Units *KirigamiPlasmaFactory::createUnits(QObject *parent)
+Kirigami::Platform::Units *KirigamiPlasmaFactory::createUnits(QObject *parent)
 {
     Q_ASSERT(parent);
     return new Units(parent);
